# Changelog

## [0.4.0] - 2023-12-31

### Added

- pypi
  - pypi metadata
  - first pypi publish


## [0.3.0] - 2024-12-29

### Added

- LICENSE  
- CHANGELOG  
- CONTRIBUTING  


## [0.2.0] - 2024-12-29

_Initial release_

[0.2.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.2.0
[0.3.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.3.0
[0.4.0]: https://gitlab.com/alex-carvalho-dockeration/doimbu/-/tags/0.4.0